@@ -87,6 +87,7 @@ def parse(html: str, p: Product, include: Sequence = None):
     should_thumbnail() and parse_thumbnail(p, selector=sel)
     "category" in include and parse_category(p, selector=sel)
     "date_first_avail" in include and parse_date_first_avail(p, selector=sel)
+    "customize" in include and parse_customize(p, html=html)
 
 
 def parse_parent_asin(p: Product, selector: parsel.Selector = None):
@@ -260,11 +261,17 @@ def parse_ship(p: Product, selector: parsel.Selector = None):
 
 
 def parse_sold(p: Product, selector: parsel.Selector = None):
-    sold = selector.xpath("//a[@id='sellerProfileTriggerId']/text()").get()
-    sold = sold or selector.xpath(
-        "normalize-space(string(//div[@id='merchant-info']))"
-    ).re_first(r"Ships from and sold by (.+)\.")
-    if sold is None:
+    def s1() -> str:
+        return selector.xpath("//a[@id='sellerProfileTriggerId']/text()").get("")
+
+    def s2() -> str:
+        text = selector.xpath("normalize-space(string(//div[@id='merchant-info']))")
+        s = text.re_first(r"Ships from and sold by (.+)\.")
+        s = s or text.re_first(r"Sold by (.+) and Fulfilled by")
+        return s or ""
+
+    sold = s1() or s2()
+    if sold == "":
         p.sold = None
     else:
         p.sold = sold
@@ -488,3 +495,7 @@ def parse_date_first_avail(p: Product, selector: parsel.Selector = None):
         p.date_first_avail = None
     else:
         p.date_first_avail = date
+
+
+def parse_customize(p: Product, html: str = None):
+    p.customize = "This product needs to be customized before adding to cart." in html
